@@ -168,6 +168,8 @@ pub struct LuaShared {
 	pub lua_getstack: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, level: i32, ar: *mut LuaDebug) -> i32>,
 	pub lua_next: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> i32>,
 	pub lua_topointer: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> *const c_void>,
+	pub lua_newuserdata: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, size: usize) -> *mut c_void>,
+	pub lual_newmetatable: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, name: LuaString) -> i32>,
 }
 unsafe impl Sync for LuaShared {}
 impl LuaShared {
@@ -232,7 +234,9 @@ impl LuaShared {
 				lua_getinfo: find_symbol!("lua_getinfo"),
 				lua_getstack: find_symbol!("lua_getstack"),
 				lua_next: find_symbol!("lua_next"),
-				lua_topointer: find_symbol!("lua_topointer")
+				lua_topointer: find_symbol!("lua_topointer"),
+				lua_newuserdata: find_symbol!("lua_newuserdata"),
+				lual_newmetatable: find_symbol!("lual_newmetatable"),
 			}
 		}
 	}
